export type EMDYData = Record<string, unknown>;
export declare class EMDYError extends Error {
    name: string;
}
export declare class EMDYParseError extends EMDYError {
    name: string;
    original?: Error;
    constructor(message: string, original?: Error);
}
/**
 * Parse a markdown document with optional YAML frontmatter into an object
 * with the markdown content and any frontmatter as keys.
 * @param content The raw markdown content
 * @param markdownKey The key to use for the markdown content
 * @returns The parsed markdown content and frontmatter
 */
export declare function parse(content: string, markdownKey?: string): EMDYData;
/**
 * Serialize an object with markdown content and optional frontmatter into a
 * Markdown document. Uses the `content` key for the markdown content by default.
 * @param data The object to serialize
 * @param markdownKey The key to use for the markdown content
 * @returns The parsed markdown content and frontmatter
 */
export declare function stringify(data: Record<string, unknown>, markdownKey?: string): string;
/**
 * Parse a multi-document file into an array of EMDYData objects
 * @param content The raw markdown content containing multiple documents
 * @param markdownKey The key to use for the markdown content in each document
 * @returns An array of parsed EMDYData objects
 */
export declare function parseAll(content: string, markdownKey?: string): EMDYData[];
declare const EMDY: {
    readonly parse: typeof parse;
    readonly parseAll: typeof parseAll;
    readonly stringify: typeof stringify;
};
export default EMDY;
